@@ -74,14 +74,16 @@ int  explicit_wmf_error (char*,wmf_error_t);
 int wmf2fig_draw (PlotData* pdata)
 {	int status = 0;
 
+#if 0
 	unsigned int wmf_width;
 	unsigned int wmf_height;
 
 	unsigned int page_width;
 	unsigned int page_height;
+#endif
 
 	unsigned long flags;
-
+#if 0
 	int page_margin;
 
 	float def_width;
@@ -89,7 +91,7 @@ int wmf2fig_draw (PlotData* pdata)
 
 	float ratio_wmf;
 	float ratio_page;
-
+#endif
 	static char* Default_Creator = "wmf2fig";
 
 	ImageContext IC;
@@ -242,7 +244,8 @@ void wmf2fig_init (PlotData* pdata,int argc,char** argv)
 }
 
 void wmf2fig_help (PlotData* pdata)
-{	fputs ("\
+{	(void)pdata;
+	fputs ("\
 Usage: wmf2fig [OPTION]... [-o <file.eps>] <file.wmf>\n\
   or:  wmf2fig [OPTION]... --auto <file1.wmf> [<file2.wmf> ...]\n\
 Convert metafile image to XFig format.\n\
@@ -498,7 +501,8 @@ int main (int argc,char** argv)
 }
 
 int explicit_wmf_error (char* str,wmf_error_t err)
-{	int status = 0;
+{	(void)str;
+	int status = 0;
 
 	switch (err)
 	{
